@@ -21,14 +21,7 @@ import click
 import matplotlib.pyplot as plt
 import mplhep
 from LbAPCommon import parse_yaml, render_yaml, validate_yaml
-from LbAPCommon.checks import (
-    branches_exist,
-    num_entries,
-    num_entries_per_invpb,
-    range_check,
-    range_check_bkg_subtracted,
-    range_check_nd,
-)
+from LbAPCommon.checks import run_job_checks
 from LbAPCommon.checks_utils import checks_to_JSON, hist_to_root
 
 from .utils import check_production
@@ -52,7 +45,7 @@ def perform_checks(production_name, job_name, test_ntuple_path_list, checks_outp
 
     if "checks" in job_data.keys():
         click.secho("Running checks", fg="green")
-        check_results = run_checks(
+        check_results = run_job_checks(
             job_data["checks"], checks_data, test_ntuple_path_list
         )
         output_check_results(job_name, checks_data, check_results, checks_output_dir)
@@ -103,83 +96,6 @@ def prepare_checks(production_name, job_name, test_ntuple_path_list, checks_outp
     return job_data, checks_data
 
 
-def run_checks(checks_list, check_data, test_ntuple_path_list):
-    """
-    Run the checks listed for the given job, using data from an ntuple made earlier (by `lb-ap test`).
-
-    Returns dict of CheckResult objects
-    """
-    check_results = {}
-
-    for check in checks_list:
-        data = check_data[check]
-        # This is added because some parameters are optional and need to be properly initialized
-        blind = data["blind_ranges"] if "blind_ranges" in data else []
-        exp_mean = data["exp_mean"] if "exp_mean" in data else 0.0
-        exp_std = data["exp_std"] if "exp_std" in data else 0.0
-        mean_tolerance = data["mean_tolerance"] if "mean_tolerance" in data else 0.0
-        std_tolerance = data["std_tolerance"] if "std_tolerance" in data else 0.0
-        tree_pattern = (
-            data["tree_pattern"]
-            if "tree_pattern" in data
-            else r"(.*/DecayTree)|(.*/MCDecayTree)"
-        )
-
-        if data["type"] == "range":
-            check_results[check] = range_check(
-                test_ntuple_path_list,
-                data["expression"],
-                data["limits"],
-                blind_ranges=blind,
-                exp_mean=exp_mean,
-                exp_std=exp_std,
-                mean_tolerance=mean_tolerance,
-                std_tolerance=std_tolerance,
-                tree_pattern=tree_pattern,
-            )
-        elif data["type"] == "range_bkg_subtracted":
-            check_results[check] = range_check_bkg_subtracted(
-                test_ntuple_path_list,
-                data["expression"],
-                data["limits"],
-                data["expr_for_subtraction"],
-                data["mean_sig"],
-                data["background_shift"],
-                data["background_window"],
-                data["signal_window"],
-                blind_ranges=blind,
-                tree_pattern=tree_pattern,
-            )
-        elif data["type"] == "range_nd":
-            check_results[check] = range_check_nd(
-                test_ntuple_path_list,
-                data["expressions"],
-                data["limits"],
-                blind_ranges=blind,
-                tree_pattern=tree_pattern,
-            )
-        elif data["type"] == "num_entries":
-            check_results[check] = num_entries(
-                test_ntuple_path_list,
-                data["count"],
-                tree_pattern=tree_pattern,
-            )
-        elif data["type"] == "num_entries_per_invpb":
-            check_results[check] = num_entries_per_invpb(
-                test_ntuple_path_list,
-                data["count_per_invpb"],
-                tree_pattern=tree_pattern,
-            )
-        elif data["type"] == "branches_exist":
-            check_results[check] = branches_exist(
-                test_ntuple_path_list,
-                data["branches"],
-                tree_pattern=tree_pattern,
-            )
-
-    return check_results
-
-
 def output_check_results(job_name, checks_data, check_results, checks_out_dir):
     """
     Handle all output from checks
