@@ -209,7 +209,7 @@ def test(production_name, job_name, dependent_input):
                 out_dir,
                 join(out_dir, "output.pkl"),
                 test_ntuple_path,
-                job_data,
+                job_name,
                 prod_data,
             )
     else:
