@@ -126,17 +126,18 @@ def prepare_test(production_name, job_name, dependent_input=None):
     output_file_type = job_data["output"].pop()
 
     # force to use the file chosen by the user
-    if "bk_query" in job_data["input"] and dependent_input is not None:
-        data["lfns"] = [dependent_input]
-
-    if "job_name" in job_data["input"]:
-        lfns = [dependent_input]
     if "bk_query" in job_data["input"]:
-        lfns = json.dumps([f"LFN:{lfn}" for lfn in data["lfns"]])
+        if dependent_input is not None:
+            lfns = [dependent_input]
+        else:
+            lfns = json.dumps([f"LFN:{lfn}" for lfn in data["lfns"]])
 
-        # only need a catalog if we're using Dirac data
-        with open(join(out_dir, "pool_xml_catalog.xml"), "wt") as fp:
-            fp.write(pool_xml_catalog(data["lfns"]))
+            # only need a catalog if we're using Dirac data
+            with open(join(out_dir, "pool_xml_catalog.xml"), "wt") as fp:
+                fp.write(pool_xml_catalog(data["lfns"]))
+
+    elif "job_name" in job_data["input"]:
+        lfns = [dependent_input]
 
     with open(join(out_dir, prod_conf_fn), "wt") as fp:
         fp.write(
@@ -249,7 +250,7 @@ def enter_debugging(out_dir, env_cmd, gaudi_cmd, dependent_job=None):
     os.execlp(cmd[0], *cmd)
 
 
-def do_options_parsing(env_cmd, out_dir, pkl_file, root_file, job_data, prod_data):
+def do_options_parsing(env_cmd, out_dir, pkl_file, root_file, job_name, prod_data):
     json_file = join(out_dir, "output.json")
 
     with importlib.resources.path(
@@ -268,4 +269,4 @@ def do_options_parsing(env_cmd, out_dir, pkl_file, root_file, job_data, prod_dat
             ],
             text=True,
         )
-    return validate_options(json_file, root_file, job_data, prod_data)
+    return validate_options(json_file, root_file, job_name, prod_data)
