@@ -26,8 +26,8 @@ def test_parse_logs(log_path):
     result = runner.invoke(main, ["parse-log", log_path])
 
     if basename(log_path).startswith("good-"):
-        assert result.exit_code == 0
+        assert result.exit_code == 0, result.stdout
     elif basename(log_path).startswith("error-"):
-        assert result.exit_code == 1
+        assert result.exit_code == 1, result.stdout
     else:
         raise NotImplementedError(log_path)
